#
# spec file for package xml-security-c
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libvers 20
Name:           xml-security-c
Version:        2.0.4
Release:        1.8
Summary:        Apache XML security C++ library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://santuario.apache.org/
Source0:        http://www.apache.org/dist/santuario/c-library/%{name}-%{version}.tar.bz2
Source1:        http://www.apache.org/dist/santuario/c-library/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
BuildRequires:  gcc-c++
BuildRequires:  libxalan-c-devel >= 1.11
BuildRequires:  libxerces-c-devel >= 3.2
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig

%description
The xml-security-c library is a C++ implementation of the XML Digital Signature
and Encryption specifications. The library makes use of the Apache XML project's
Xerces-C XML Parser and Xalan-C XSLT processor. The latter is used for processing
XPath and XSLT transforms.

%package -n xml-security-c-bin
Summary:        Utilities for XML security C++ library
Group:          Development/Libraries/C and C++

%description -n xml-security-c-bin
The xml-security-c library is a C++ implementation of the XML Digital Signature
and Encryption specifications. The library makes use of the Apache XML project's
Xerces-C XML Parser and Xalan-C XSLT processor. The latter is used for processing
XPath and XSLT transforms.

This package contains the utility programs.

%package -n libxml-security-c%{libvers}
Summary:        Apache XML security C++ library
Group:          Development/Libraries/C and C++
Provides:       xml-security-c = %{version}-%{release}
Obsoletes:      xml-security-c < %{version}-%{release}

%description -n libxml-security-c%{libvers}
The xml-security-c library is a C++ implementation of the XML Digital Signature
and Encryption specifications. The library makes use of the Apache XML project's
Xerces-C XML Parser and Xalan-C XSLT processor. The latter is used for processing
XPath and XSLT transforms.

This package contains just the shared library.

%package -n libxml-security-c-devel
Summary:        Development files for the Apache C++ XML security library
Group:          Development/Libraries/C and C++
Requires:       libxalan-c-devel >= 1.11
Requires:       libxerces-c-devel
Requires:       libxml-security-c%{libvers} = %{version}-%{release}
Requires:       openssl-devel
Provides:       xml-security-c-devel = %{version}-%{release}
Obsoletes:      xml-security-c-devel < %{version}-%{release}

%description -n libxml-security-c-devel
The xml-security-c library is a C++ implementation of the XML Digital Signature
and Encryption specifications. The library makes use of the Apache XML project's
Xerces-C XML Parser and Xalan-C XSLT processor. The latter is used for processing
XPath and XSLT transforms.

This package includes files needed for development with xml-security-c.

%prep
%setup -q
%autopatch -p1

%build
%configure \
  --disable-static
%make_build

%install
%make_install
rm -rf %{buildroot}/%{_libdir}/libxml-security-c.la

%post -n libxml-security-c%{libvers} -p /sbin/ldconfig
%postun -n libxml-security-c%{libvers} -p /sbin/ldconfig

%files -n xml-security-c-bin
%license LICENSE.txt
%doc CHANGELOG.txt
%{_bindir}/*

%files -n libxml-security-c%{libvers}
%license LICENSE.txt
%doc CHANGELOG.txt
%{_libdir}/*.so.*

%files -n libxml-security-c-devel
%license LICENSE.txt
%doc CHANGELOG.txt
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/xml-security-c.pc

%changelog
* Mon Nov  8 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 2.0.4: no changelog available
- Drop xml-security-c-2.0.2-xalan-1.12.patch
* Wed Feb 17 2021 Kristyna Streitova <kstreitova@suse.com>
- add xml-security-c-2.0.2-xalan-1.12.patch to fix build with xalan
  1.12 [bsc#1179556]
- re-enable xalan support
* Tue Dec  1 2020 Kristyna Streitova <kstreitova@suse.com>
- Run spec-cleaner
- Temporarily disable xalan support because it fails with the recent
  1.12 version
* Tue Nov 27 2018 kstreitova@suse.com
- update to 2.0.2
  * [SANTUARIO-496] - DSA verification crashes OpenSSL on invalid
    combinations of key content
  * [SANTUARIO-491] - Default KeyInfo resolver doesn't check for
    empty element content.
  * [SANTUARIO-382] - Unconditionally enable large file support
  * [SANTUARIO-418] - Invalid acceptance of unpadded RSA signatures
  * [SANTUARIO-435] - Automake misses the subdir-objects option
  * [SANTUARIO-437] - Cannot compile as C++11
  * [SANTUARIO-447] - XSECCryptoX509::loadX509PEM() can read past
    unterminated buffer
  * [SANTUARIO-449] - TXFMOutputFile can try to close unopened stream
  * [SANTUARIO-470] - dsig/DSIGReference.cpp:931: bad type ?
  * [SANTUARIO-471] - Patch for C++11 compile failures
  * [SANTUARIO-473] - Build failure using NSS
  * [SANTUARIO-474] - Better overflow checking
  * [SANTUARIO-479] - xml-security-cpp compilation errors
  * [SANTUARIO-460] - Support for OpenSSL 1.1
  * [SANTUARIO-461] - Internal key store should be deleted on any
    CryptoAcquireContext() error
  * [SANTUARIO-472] - Conditional inclusion of XMKS code in library
  * [SANTUARIO-476] - Change default behavior for inferring
    attribute IDness by name
- drop the following patches that are no longer needed
  * xml-security-c-1.7.3-gcc6.patch
  * xml-security-c-1.7.3_openssl1.1.patch
- update soname from 17 to 20
- pack xml-security-c.pc
- require libxerces-c-devel >= 3.2
- run spec-cleaner
* Thu Nov  9 2017 vcizek@suse.com
- support building with openssl 1.1 (bsc#1067411)
  * add xml-security-c-1.7.3_openssl1.1.patch from Fedora
* Sun Jul  3 2016 i@marguerite.su
- add patch xml-security-c-1.7.3-gcc6.patch, fixed boo#985160
  * bool can't be converted to pointer in c++11 which is
    default in gcc6, change to NULL.
* Tue Aug 11 2015 mpluskal@suse.com
- Package license and provided changelog
* Wed Aug  5 2015 mpluskal@suse.com
- Add gpg signature
- Disable building of static libraries
- Enable xalan support
* Mon Jul 27 2015 kstreitova@suse.com
- use spec-cleaner
- package cleaning
- remove unused conditionals
* Fri Jul 24 2015 kstreitova@suse.com
- initial revision
